sp1-gpu-basefold 6.1.0

GPU-accelerated BaseFold polynomial commitment protocol
docs.rs failed to build sp1-gpu-basefold-6.1.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: sp1-gpu-basefold-6.2.3

sp1-gpu-basefold

GPU-accelerated BaseFold polynomial commitment protocol.

Implements the BaseFold polynomial commitment scheme on GPU, providing efficient polynomial encoding and commitment operations with CUDA acceleration.


Part of SP1-GPU, the GPU-accelerated prover for SP1.